@@ -30,7 +30,8 @@
 
 from startrek import Hub, Channel, Connection, ConnectionDelegate
 from startrek import ConnectionState, ConnectionStateMachine
-from startrek import BaseHub, BaseChannel, BaseConnection, ActiveConnection
+from startrek import BaseChannel, ChannelReader, ChannelWriter
+from startrek import BaseHub, BaseConnection, ActiveConnection
 
 from startrek import Ship, ShipDelegate, Arrival, Departure, DeparturePriority
 from startrek import Docker, Gate, GateStatus, GateDelegate
@@ -39,7 +40,7 @@ from startrek import ArrivalShip, ArrivalHall, DepartureShip, DepartureHall
 from startrek import Dock, LockedDock, StarDocker, StarGate
 
 from .startrek import PackageArrival, PackageDeparture, PackageDocker
-from .channel import PackageChannel
+from .channel import PackageChannel, PackageChannelReader, PackageChannelWriter
 from .hub import PackageHub, ServerHub, ClientHub
 
 name = "UDP"
@@ -50,7 +51,8 @@ __all__ = [
 
     'Hub', 'Channel', 'Connection', 'ConnectionDelegate',
     'ConnectionState', 'ConnectionStateMachine',
-    'BaseHub', 'BaseChannel', 'BaseConnection', 'ActiveConnection',
+    'BaseChannel', 'ChannelReader', 'ChannelWriter',
+    'BaseHub', 'BaseConnection', 'ActiveConnection',
     'Ship', 'ShipDelegate', 'Arrival', 'Departure', 'DeparturePriority',
     'Docker', 'Gate', 'GateStatus', 'GateDelegate',
     'ArrivalShip', 'ArrivalHall', 'DepartureShip', 'DepartureHall',
@@ -58,7 +60,6 @@ __all__ = [
 
     'PackageArrival', 'PackageDeparture', 'PackageDocker',
 
-    'PackageChannel',
-    'PackageHub',
-    'ServerHub', 'ClientHub',
+    'PackageChannel', 'PackageChannelReader', 'PackageChannelWriter',
+    'PackageHub', 'ServerHub', 'ClientHub',
 ]
